const schema = require('./schema');
const server = require('apollo-server-lambda');
const Raven = require('raven');
const RavenLambdaWrapper = require('serverless-sentry-lib');
const authHeaderParser = require('./util/authHeaderParser');
const { generateDatabase } = require('./util/databaseGenerator');

module.exports.graphql = RavenLambdaWrapper.handler(Raven, async (event, context, callback) => {
  // getting the authorization header.
  const gqlContext = authHeaderParser(event);

  // adding cors
  const callbackFilter = (error, output) => {
    output.headers['Access-Control-Allow-Origin'] = '*';
    callback(error, output);
  };

  return server.graphqlLambda({
    schema,
    context: gqlContext,
  })(event, context, callbackFilter);
});

module.exports.graphiql = (event, context, callback) => {
  const handler = server.graphiqlLambda({
    endpointURL: `/${process.env.STAGE}/graphql`,
  });
  return handler(event, context, callback);
};

module.exports.generateDatabase = () => generateDatabase();
