const applicantService = require('../services/applicantService');
const applicationService = require('../services/applicationService');
const { baSendReminderEmail } = require('@lagenhetsbyte/message-service');
const moment = require('moment');

const successResponse = (callback, response) => {
  callback(null, {
    statusCode: 200,
    body: JSON.stringify({
      status: 'SUCCESS',
      message: response.items,
    }),
  });
};

const errorResponse = (callback, response) => {
  callback(null, {
    statusCode: 400,
    body: JSON.stringify({
      status: 'FAILED',
      message: response,
    }),
  });
};

const isEverythingApprovedOrUpdated = (applicant) => {
  if ((applicant.member1.approvalStatus && applicant.member1.approvalStatus.type !== 'APPROVED') ||
      (applicant.member1.approvalStatus && applicant.member1.approvalStatus.type !== 'UPDATED')) return false;

  if ((applicant.member2 && applicant.member2.approvalStatus && applicant.member2.approvalStatus.type !== 'APPROVED') ||
      (applicant.member2 && applicant.member2.approvalStatus && applicant.member2.approvalStatus.type !== 'UPDATED')) return false;


  if ((applicant.apartment1.approvalStatus && applicant.apartment1.approvalStatus.type !== 'APPROVED') ||
      (applicant.apartment1.approvalStatus && applicant.apartment1.approvalStatus.type !== 'UPDATED')) return false;

  if ((applicant.apartment2 && applicant.apartment2.approvalStatus && applicant.apartment2.approvalStatus.type !== 'APPROVED') ||
      (applicant.apartment2 && applicant.apartment2.approvalStatus && applicant.apartment2.approvalStatus.type !== 'UPDATED')) return false;


  if ((applicant.details1.approvalStatus && applicant.details1.approvalStatus.type !== 'APPROVED') ||
      (applicant.details1.approvalStatus && applicant.details1.approvalStatus.type !== 'UPDATED')) return false;

  if ((applicant.details2 && applicant.details2.approvalStatus && applicant.details2.approvalStatus.type !== 'APPROVED') ||
      (applicant.details2 && applicant.details2.approvalStatus && applicant.details2.approvalStatus.type !== 'UPDATED')) return false;


  if ((applicant.swapReason.approvalStatus && applicant.swapReason.approvalStatus.type !== 'APPROVED') ||
      (applicant.swapReason.approvalStatus && applicant.swapReason.approvalStatus.type !== 'UPDATED')) return false;

  return true;
};

const inReminderMailDateCycle = (applicant) => {
  //  applicant.lastActive = moment().year('2018').month('7').date('3'); // mock data

  const lastActiveDate = moment(applicant.lastActive);
  const currentDate = moment();
  const daysDiff = moment.duration(currentDate.diff(lastActiveDate)).asDays(); // get difference as days between last active and now
  if (daysDiff >= 3 && daysDiff <= 12 && daysDiff % 3 === 0) {
    return true;
  }
  return false;
};

const shouldSendEmail = (applicant) => {
  if (!inReminderMailDateCycle(applicant)) return false;
  if (isEverythingApprovedOrUpdated(applicant)) return false;
  return true;
};

const sendEmailToApplication = async (applicationId) => {
  const applicants = await applicantService.getByApplication(applicationId);
  applicants.forEach((applicant) => {
    if (shouldSendEmail(applicant) && process.env.STAGE === 'prod') {
      console.log(`Sending reminder email to: ${applicant.email}`);
      baSendReminderEmail(applicant.email, applicant.name, `https://bytesansokan.lagenhetsbyte.se/?propositionid=${applicant.id}`);
    }
  });
};

module.exports.reminderEmails = async (event, context, callback) => {
  await applicationService.getAll()
    .then((response) => {
      response.items.forEach((application) => {
        sendEmailToApplication(application.id);
      });
    })
    .catch((err) => {
      console.log(err);
      errorResponse(callback, err);
    });

  successResponse(callback, ':P');
};
