const adminService = require('../services/adminService');
const {
  applicants,
  adminAnonymizeApplicant,
  putApplicant,
  startApplicant,
  Applicant,
  Member,
  putMember,
  deleteMember2,
  approveMember,
  rejectMember,
  Apartment,
  putApartment,
  approveApartment,
  rejectApartment,
  Details,
  putDetails,
  approveDetails,
  rejectDetails,
  putSwapReason,
  approveSwapReason,
  setMemberSignLink,
  rejectSwapReason,
  SwapReason,
  signApplicant,
  unSignApplicant,
  reviewApplicant,
  setLastActive,
} = require('../resolvers/applicantResolver');
const {
  adminApplications,
  adminApplication,
  applications,
  application,
  reactivateApplication,
  inactivateApplication,
  setApplicationStatus,
  putApplication,
  Application,
} = require('../resolvers/applicationResolver');
const {
  adminRemoveDocument,
  approveDocument,
  rejectDocument,
  removeDocument,
  replaceDocument,
  uploadDocument,
  documents,
  Document,
} = require('../resolvers/documentResolver');

const { Admin } = require('../resolvers/adminResolver');

const resolvers = {
  Query: {
    // Application
    adminApplications,
    adminApplication,
    applications,
    application,

    // Applicant
    applicants,

    // Document
    documents,
  },
  Mutation: {
    // Application
    putApplication,
    setApplicationStatus,
    reactivateApplication,
    inactivateApplication,

    // Applicant
    adminAnonymizeApplicant,
    putApplicant,
    reviewApplicant,
    startApplicant,
    signApplicant,
    unSignApplicant,
    setLastActive,

    // Document
    adminRemoveDocument,
    approveDocument,
    rejectDocument,
    removeDocument,
    replaceDocument,
    uploadDocument,

    // Member
    putMember,
    approveMember,
    deleteMember2,
    rejectMember,
    setMemberSignLink,

    // Apartment
    putApartment,
    approveApartment,
    rejectApartment,

    // Details
    putDetails,
    approveDetails,
    rejectDetails,

    // Swap Reason
    putSwapReason,
    approveSwapReason,
    rejectSwapReason,
  },

  // Field resolvers
  Admin,
  ApprovalStatus: {
    admin: ({ admin }) => admin && adminService.get(admin),
  },
  Application,
  Applicant,
  Document,
  Member,
  Apartment,
  Details,
  SwapReason,
};

module.exports = resolvers;
