const ServiceBase = require('./serviceBase');
const applicationService = require('./applicantService');
const uuid = require('uuid/v4');
const lodash = require('lodash');

class ApplicationService extends ServiceBase {
  constructor() {
    super(lodash.get(process, 'env.APPLICATIONS_TABLE'));
  }

  async get(id) {
    const response = await this.dynamoDb.get({
      TableName: this.tableName,
      Key: { id },
    }).promise();
    return response.Item;
  }

  async getByStatus(status) {
    const response = this.dynamoDb.get({
      TableName: this.tableName,
      IndexName: 'status-index',
      KeyConditionExpression: 'status = :status',
      ExpressionAttributeValues: {
        ':status': status,
      },
    }).promise();

    return response.Items;
  }

  async putApplication(obj) {
    if (obj.id === undefined) {
      obj.id = uuid();
    }

    const { applicants } = obj;

    applicants.forEach((applicant, index) => {
      applicant.index = index;
      applicant.application = obj.id;
      applicationService.put(applicant);
    });

    const applicationObj = { id: obj.id, status: 'ACTIVE' };

    await this.dynamoDb.put({
      TableName: this.tableName,
      Item: applicationObj,
    }).promise();

    return obj;
  }
}

module.exports = new ApplicationService();
