const ServiceBase = require('./serviceBase');
const lodash = require('lodash');
const AWS = require('aws-sdk');

class DocumentService extends ServiceBase {
  constructor() {
    super(lodash.get(process, 'env.DOCUMENTS_TABLE'));
  }

  async getByApplicant(applicantId) {
    const response = await this.dynamoDb.query({
      TableName: this.tableName,
      IndexName: 'applicant-index',
      KeyConditionExpression: 'applicant = :id',
      ExpressionAttributeValues: {
        ':id': applicantId,
      },
    }).promise();
    return response.Items;
  }

  async approve(admin, documentId) {
    const document = await this.get(documentId);
    document.approvalStatus = {
      admin,
      date: Date.now(),
      type: 'APPROVED',
    };

    return this.update(document);
  }

  async reject(admin, documentId, message) {
    const document = await this.get(documentId);
    // set values
    document.approvalStatus = {
      admin,
      date: Date.now(),
      type: 'REJECTED',
      message,
    };

    return this.update(document);
  }

  removeFromS3(fileName, folder) {
    const s3 = new AWS.S3();
    const params = {
      Bucket: lodash.get(process, 'env.BUCKET_NAME'),
      Key: `private/${folder}/${fileName}`,
    };
    return s3.deleteObject(params).promise();
  }
}

module.exports = new DocumentService();
