const uuid = require('uuid/v4');
const Chance = require('chance');
const adminService = require('../services/adminService');
const applicantService = require('../services/applicantService');
const documentService = require('../services/documentService');
const applicationService = require('../services/applicationService');

const chance = new Chance();

const createIds = (count) => {
  const idList = [];
  for (let index = 0; index < count; index++) {
    idList.push(uuid());
  }
  return idList;
};

const createEmails = (count) => {
  const idList = [];
  for (let index = 0; index < count; index++) {
    idList.push(chance.email());
  }
  return idList;
};

const pushToDatabase = (
  applicantsPerApplication,
  applicationIds,
  applicantIds,
  emails,
  cognitoIds,
  documentIds,
  mockAdmin,
) => {
  const promises = [];
  // create 5 applications
  let aIndex = 0;
  let dIndex = 0;
  let cIndex = 0;
  let eIndex = 0;
  for (let index = 0; index < applicationIds.length; index++) {
    const aIds = [];
    for (let i = 0; i < applicantsPerApplication; i++) {
      aIds.push({
        id: applicantIds[aIndex++],
        email: emails[eIndex++],
      });
    }
    const applicationObject = {
      id: applicationIds[index],
      status: 'ACTIVE',
      // order: aIds.map(aid => aid.id).join(','),
      // applicants: aIds.map(a => a.id),
    };
    promises.push(applicationService.put(applicationObject));

    for (let j = 0; j < aIds.length; j++) {
      const a = aIds[j];
      const swapApplicant = aIds[(j + 1) % (aIds.length)];
      const cognitoId = cognitoIds[cIndex++];
      const applicant = {
        id: a.id,
        index: j,
        swapDate: Date.now(),
        cognitoId,
        image: 'http://thecatapi.com/api/images/get?format=src&type=jpg&size=med',
        email: a.email,
        application: applicationIds[index],
        member1: {
          cognitoId,
          name: chance.name(),
          email: a.email,
          ssn: chance.ssn(),
          phone: chance.phone(),
          registeredAddress: chance.address(),
        },
        member2: {
          cognitoId,
          name: chance.name(),
          email: a.email,
          ssn: chance.ssn(),
          phone: chance.phone(),
          registeredAddress: chance.address(),
        },
        apartment1: {
          cognitoId,
          landlord: chance.company(),
          address: chance.address(),
          postalCode: chance.postal(),
          city: chance.city(),
        },
        apartment2: {
          cognitoId,
          landlord: chance.company(),
          address: chance.address(),
          postalCode: chance.postal(),
          city: chance.city(),
        },
        details1: {
          cognitoId,
          applicantId: a.id,
          memberIndex: 'ONE',
          apartmentId: swapApplicant.id,
          apartmentIndex: 'ONE',
          personCount: 4,
          childrenCount: 2,
        },
        details2: {
          cognitoId,
          applicantId: a.id,
          memberIndex: 'TWO',
          apartmentId: swapApplicant.id,
          apartmentIndex: 'TWO',
          personCount: 4,
          childrenCount: 2,
        },
        swapReason: {
          freeText: chance.string(),
          cognitoId,
        },
        bankId: {
          ssn: chance.ssn(),
          date: Date.now(),
        },
      };
      promises.push(applicantService.put(applicant));

      const document = {
        id: documentIds[dIndex++],
        cognitoId,
        email: a.email,
        applicant: a.id,
        folder: `eu-west-1:${uuid()}`,
        type: 'ID_PROOF',
        fileName: 'file.pdf',
        // approvalStatus: ,
        uploadedAt: Date.now(),
      };
      promises.push(documentService.put(document));
    }
  }

  if (mockAdmin) promises.push(adminService.put(mockAdmin));

  return Promise.all(promises)
    .then((response) => {
    }).catch(error => console.log(error));
};

const generateDatabase = () => {
  const applicationCount = 5;
  let applicantsPerApplication = 3;
  let applicationIds = createIds(applicationCount);
  let applicantIds = createIds(applicationCount * applicantsPerApplication);
  let documentIds = createIds(applicationCount * applicantsPerApplication);
  let cognitoIds = createIds(applicationCount * applicantsPerApplication);
  let emails = createEmails(applicationCount * applicantsPerApplication);

  applicantIds[0] = '9a583c06-b439-400e-8327-f6ef3afe2334';
  cognitoIds[0] = '78fa3e45-6fb1-4307-9659-87e15de7f221';
  emails[0] = 'ashlaf@lagenhetsbyte.com';

  pushToDatabase(applicantsPerApplication, applicationIds, applicantIds, emails, cognitoIds, documentIds, false);

  applicantsPerApplication = 2;
  applicationIds = createIds(applicationCount);
  applicantIds = createIds(applicationCount * applicantsPerApplication);
  documentIds = createIds(applicationCount * applicantsPerApplication);
  cognitoIds = createIds(applicationCount * applicantsPerApplication);
  emails = createEmails(applicationCount * applicantsPerApplication);
  applicantIds[0] = '365b18e5-b439-48fa-8327-8b6bb88c991e';
  cognitoIds[0] = 'dff3d3b4-6baa-48fa-9507-ab6658b75dfe';
  emails[0] = 'henrik.mattsson@hotmail.com';

  pushToDatabase(applicantsPerApplication, applicationIds, applicantIds, emails, cognitoIds, documentIds, false);
};

module.exports = {
  generateDatabase,
  pushToDatabase,
};
